from wpath import Atts
from tests.test_fox import Fox

Atts.show(Fox("Tom", name="Kate", sex="female"), show_parents=True)

